@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Module::CoreList;
 
-our $VERSION = '5.20220720';
+our $VERSION = '5.20220820';
 our %utilities;
 
 sub utilities {
@@ -1825,6 +1825,13 @@ my %delta = (
         removed => {
         }
     },
+    5.037003 => {
+        delta_from => 5.037002,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
